@@ -1,4 +1,4 @@
-"""Unicode Properties from Unicode version 15.1.0 (autogen)."""
+"""Unicode Properties from Unicode version 16.0.0 (autogen)."""
 from __future__ import annotations
 
 unicode_alias: dict[str, dict[str, str]] = {
@@ -42,6 +42,7 @@ unicode_alias: dict[str, dict[str, str]] = {
         "v140": "14.0",
         "v150": "15.0",
         "v151": "15.1",
+        "v160": "16.0",
         "v20": "2.0",
         "v21": "2.1",
         "v30": "3.0",
@@ -136,6 +137,7 @@ unicode_alias: dict[str, dict[str, str]] = {
         "loe": "logicalorderexception",
         "lower": "lowercase",
         "math": "math",
+        "mcm": "modifiercombiningmark",
         "nchar": "noncharactercodepoint",
         "oalpha": "otheralphabetic",
         "odi": "otherdefaultignorablecodepoint",
@@ -220,6 +222,7 @@ unicode_alias: dict[str, dict[str, str]] = {
         "diacriticalsforsymbols": "combiningdiacriticalmarksforsymbols",
         "diacriticalssup": "combiningdiacriticalmarkssupplement",
         "domino": "dominotiles",
+        "egyptianhieroglyphsexta": "egyptianhieroglyphsextendeda",
         "enclosedalphanum": "enclosedalphanumerics",
         "enclosedalphanumsup": "enclosedalphanumericsupplement",
         "enclosedcjk": "enclosedcjklettersandmonths",
@@ -276,6 +279,7 @@ unicode_alias: dict[str, dict[str, str]] = {
         "music": "musicalsymbols",
         "myanmarexta": "myanmarextendeda",
         "myanmarextb": "myanmarextendedb",
+        "myanmarextc": "myanmarextendedc",
         "nb": "noblock",
         "ocr": "opticalcharacterrecognition",
         "phaistos": "phaistosdisc",
@@ -299,6 +303,7 @@ unicode_alias: dict[str, dict[str, str]] = {
         "suppunctuation": "supplementalpunctuation",
         "supsymbolsandpictographs": "supplementalsymbolsandpictographs",
         "symbolsandpictographsexta": "symbolsandpictographsextendeda",
+        "symbolsforlegacycomputingsup": "symbolsforlegacycomputingsupplement",
         "syriacsup": "syriacsupplement",
         "taixuanjing": "taixuanjingsymbols",
         "tamilsup": "tamilsupplement",
@@ -603,6 +608,7 @@ unicode_alias: dict[str, dict[str, str]] = {
         "elba": "elbasan",
         "elym": "elymaic",
         "ethi": "ethiopic",
+        "gara": "garay",
         "geor": "georgian",
         "glag": "glagolitic",
         "gong": "gunjalagondi",
@@ -611,6 +617,7 @@ unicode_alias: dict[str, dict[str, str]] = {
         "gran": "grantha",
         "grek": "greek",
         "gujr": "gujarati",
+        "gukh": "gurungkhema",
         "guru": "gurmukhi",
         "hang": "hangul",
         "hani": "han",
@@ -632,6 +639,7 @@ unicode_alias: dict[str, dict[str, str]] = {
         "khoj": "khojki",
         "kits": "khitansmallscript",
         "knda": "kannada",
+        "krai": "kiratrai",
         "kthi": "kaithi",
         "lana": "taitham",
         "laoo": "lao",
@@ -665,6 +673,7 @@ unicode_alias: dict[str, dict[str, str]] = {
         "nshu": "nushu",
         "ogam": "ogham",
         "olck": "olchiki",
+        "onao": "olonal",
         "orkh": "oldturkic",
         "orya": "oriya",
         "osge": "osage",
@@ -698,6 +707,7 @@ unicode_alias: dict[str, dict[str, str]] = {
         "sora": "sorasompeng",
         "soyo": "soyombo",
         "sund": "sundanese",
+        "sunu": "sunuwar",
         "sylo": "sylotinagri",
         "syrc": "syriac",
         "tagb": "tagbanwa",
@@ -714,6 +724,8 @@ unicode_alias: dict[str, dict[str, str]] = {
         "tibt": "tibetan",
         "tirh": "tirhuta",
         "tnsa": "tangsa",
+        "todr": "todhri",
+        "tutg": "tulutigalari",
         "ugar": "ugaritic",
         "vaii": "vai",
         "vith": "vithkuqi",
