@@ -1,4 +1,4 @@
-"""Unicode Properties from Unicode version 15.1.0 (autogen)."""
+"""Unicode Properties from Unicode version 16.0.0 (autogen)."""
 from __future__ import annotations
 
 unicode_joining_group: dict[str, str] = {
@@ -11,7 +11,7 @@ unicode_joining_group: dict[str, str] = {
     "^beh": "\x00-\u0627\u0629\u062c-\u066d\u066f-\u0678\u0681-\u074f\u0757-\u089f\u08a2-\u08b5\u08b9-\u08bd\u08c1-\U0010ffff",
     "^beth": "\x00-\u0711\u0713-\u072c\u072e-\U0010ffff",
     "^burushaskiyehbarree": "\x00-\u0779\u077c-\U0010ffff",
-    "^dal": "\x00-\u062e\u0631-\u0687\u0691-\u06ed\u06ef-\u0758\u075b-\u08ad\u08af-\U0010ffff",
+    "^dal": "\x00-\u062e\u0631-\u0687\u0691-\u06ed\u06ef-\u0758\u075b-\u08ad\u08af-\U00010ec1\U00010ec3-\U0010ffff",
     "^dalathrish": "\x00-\u0714\u0717-\u0729\u072b-\u072e\u0730-\U0010ffff",
     "^e": "\x00-\u0724\u0726-\U0010ffff",
     "^farsiyeh": "\x00-\u063c\u0640-\u06cb\u06cd\u06cf-\u0774\u0777-\U0010ffff",
@@ -27,8 +27,9 @@ unicode_joining_group: dict[str, str] = {
     "^heh": "\x00-\u0646\u0648-\U0010ffff",
     "^hehgoal": "\x00-\u06c0\u06c3-\U0010ffff",
     "^heth": "\x00-\u0719\u071b-\U0010ffff",
-    "^kaf": "\x00-\u0642\u0644-\u06ab\u06af-\u077e\u0780-\u08b3\u08b5-\U0010ffff",
+    "^kaf": "\x00-\u0642\u0644-\u06ab\u06af-\u077e\u0780-\u08b3\u08b5-\U00010ec3\U00010ec5-\U0010ffff",
     "^kaph": "\x00-\u071e\u0720-\U0010ffff",
+    "^kashmiriyeh": "\x00-\u061f\u0621-\U0010ffff",
     "^khaph": "\x00-\u074d\u074f-\U0010ffff",
     "^knottedheh": "\x00-\u06bd\u06bf-\u06fe\u0700-\U0010ffff",
     "^lam": "\x00-\u0643\u0645-\u06b4\u06b9-\u0769\u076b-\u08a5\u08a7-\u08c6\u08c8-\U0010ffff",
@@ -73,7 +74,7 @@ unicode_joining_group: dict[str, str] = {
     "^manichaeanzayin": "\x00-\U00010ac8\U00010acb-\U0010ffff",
     "^meem": "\x00-\u0644\u0646-\u0764\u0767-\u08a6\u08a8-\U0010ffff",
     "^mim": "\x00-\u0720\u0722-\U0010ffff",
-    "^nonjoining": "\u0620\u0622-\u063f\u0641-\u064a\u066e-\u066f\u0671-\u0673\u0675-\u06d3\u06d5\u06ee-\u06ef\u06fa-\u06fc\u06ff\u0710\u0712-\u072f\u074d-\u077f\u0860-\u086a\u0870-\u0882\u0886\u0889-\u088e\u08a0-\u08ac\u08ae-\u08c8\U00010ac0-\U00010ac5\U00010ac7\U00010ac9-\U00010aca\U00010acd-\U00010ae1\U00010ae4\U00010aeb-\U00010aef\U00010d02\U00010d09\U00010d19\U00010d1c\U00010d1e\U00010d20\U00010d23",
+    "^nonjoining": "\u0620\u0622-\u063f\u0641-\u064a\u066e-\u066f\u0671-\u0673\u0675-\u06d3\u06d5\u06ee-\u06ef\u06fa-\u06fc\u06ff\u0710\u0712-\u072f\u074d-\u077f\u0860-\u086a\u0870-\u0882\u0886\u0889-\u088e\u08a0-\u08ac\u08ae-\u08c8\U00010ac0-\U00010ac5\U00010ac7\U00010ac9-\U00010aca\U00010acd-\U00010ae1\U00010ae4\U00010aeb-\U00010aef\U00010d02\U00010d09\U00010d19\U00010d1c\U00010d1e\U00010d20\U00010d23\U00010ec2-\U00010ec4",
     "^noon": "\x00-\u0645\u0647-\u06b8\u06bd-\u0766\u076a-\u0888\u088a-\U0010ffff",
     "^nun": "\x00-\u0721\u0723-\U0010ffff",
     "^nya": "\x00-\u06bc\u06be-\U0010ffff",
@@ -91,7 +92,7 @@ unicode_joining_group: dict[str, str] = {
     "^straightwaw": "\x00-\u08b0\u08b2-\U0010ffff",
     "^swashkaf": "\x00-\u06a9\u06ab-\U0010ffff",
     "^syriacwaw": "\x00-\u0717\u0719-\U0010ffff",
-    "^tah": "\x00-\u0636\u0639-\u069e\u06a0-\u088a\u088d-\u08a2\u08a4-\U0010ffff",
+    "^tah": "\x00-\u0636\u0639-\u069e\u06a0-\u088a\u088d-\u08a2\u08a4-\U00010ec2\U00010ec4-\U0010ffff",
     "^taw": "\x00-\u072b\u072d-\U0010ffff",
     "^tehmarbuta": "\x00-\u0628\u062a-\u06bf\u06c1-\u06d4\u06d6-\U0010ffff",
     "^tehmarbutagoal": "\x00-\u06c2\u06c4-\U0010ffff",
@@ -99,7 +100,7 @@ unicode_joining_group: dict[str, str] = {
     "^thinyeh": "\x00-\u0885\u0887-\U0010ffff",
     "^verticaltail": "\x00-\u088d\u088f-\U0010ffff",
     "^waw": "\x00-\u0623\u0625-\u0647\u0649-\u0675\u0678-\u06c3\u06cc-\u06ce\u06d0-\u0777\u077a-\u08aa\u08ac-\U0010ffff",
-    "^yeh": "\x00-\u061f\u0621-\u0625\u0627-\u0648\u064b-\u0677\u0679-\u06cf\u06d2-\u0776\u0778-\u08a7\u08aa-\u08b9\u08bb-\U0010ffff",
+    "^yeh": "\x00-\u0625\u0627-\u0648\u064b-\u0677\u0679-\u06cf\u06d2-\u0776\u0778-\u08a7\u08aa-\u08b9\u08bb-\U0010ffff",
     "^yehbarree": "\x00-\u06d1\u06d4-\U0010ffff",
     "^yehwithtail": "\x00-\u06cc\u06ce-\U0010ffff",
     "^yudh": "\x00-\u071c\u071e-\U0010ffff",
@@ -115,7 +116,7 @@ unicode_joining_group: dict[str, str] = {
     "beh": "\u0628\u062a-\u062b\u066e\u0679-\u0680\u0750-\u0756\u08a0-\u08a1\u08b6-\u08b8\u08be-\u08c0",
     "beth": "\u0712\u072d",
     "burushaskiyehbarree": "\u077a-\u077b",
-    "dal": "\u062f-\u0630\u0688-\u0690\u06ee\u0759-\u075a\u08ae",
+    "dal": "\u062f-\u0630\u0688-\u0690\u06ee\u0759-\u075a\u08ae\U00010ec2",
     "dalathrish": "\u0715-\u0716\u072a\u072f",
     "e": "\u0725",
     "farsiyeh": "\u063d-\u063f\u06cc\u06ce\u0775-\u0776",
@@ -131,8 +132,9 @@ unicode_joining_group: dict[str, str] = {
     "heh": "\u0647",
     "hehgoal": "\u06c1-\u06c2",
     "heth": "\u071a",
-    "kaf": "\u0643\u06ac-\u06ae\u077f\u08b4",
+    "kaf": "\u0643\u06ac-\u06ae\u077f\u08b4\U00010ec4",
     "kaph": "\u071f",
+    "kashmiriyeh": "\u0620",
     "khaph": "\u074e",
     "knottedheh": "\u06be\u06ff",
     "lam": "\u0644\u06b5-\u06b8\u076a\u08a6\u08c7",
@@ -177,7 +179,7 @@ unicode_joining_group: dict[str, str] = {
     "manichaeanzayin": "\U00010ac9-\U00010aca",
     "meem": "\u0645\u0765-\u0766\u08a7",
     "mim": "\u0721",
-    "nonjoining": "\x00-\u061f\u0621\u0640\u064b-\u066d\u0670\u0674\u06d4\u06d6-\u06ed\u06f0-\u06f9\u06fd-\u06fe\u0700-\u070f\u0711\u0730-\u074c\u0780-\u085f\u086b-\u086f\u0883-\u0885\u0887-\u0888\u088f-\u089f\u08ad\u08c9-\U00010abf\U00010ac6\U00010ac8\U00010acb-\U00010acc\U00010ae2-\U00010ae3\U00010ae5-\U00010aea\U00010af0-\U00010d01\U00010d03-\U00010d08\U00010d0a-\U00010d18\U00010d1a-\U00010d1b\U00010d1d\U00010d1f\U00010d21-\U00010d22\U00010d24-\U0010ffff",
+    "nonjoining": "\x00-\u061f\u0621\u0640\u064b-\u066d\u0670\u0674\u06d4\u06d6-\u06ed\u06f0-\u06f9\u06fd-\u06fe\u0700-\u070f\u0711\u0730-\u074c\u0780-\u085f\u086b-\u086f\u0883-\u0885\u0887-\u0888\u088f-\u089f\u08ad\u08c9-\U00010abf\U00010ac6\U00010ac8\U00010acb-\U00010acc\U00010ae2-\U00010ae3\U00010ae5-\U00010aea\U00010af0-\U00010d01\U00010d03-\U00010d08\U00010d0a-\U00010d18\U00010d1a-\U00010d1b\U00010d1d\U00010d1f\U00010d21-\U00010d22\U00010d24-\U00010ec1\U00010ec5-\U0010ffff",
     "noon": "\u0646\u06b9-\u06bc\u0767-\u0769\u0889",
     "nun": "\u0722",
     "nya": "\u06bd",
@@ -195,7 +197,7 @@ unicode_joining_group: dict[str, str] = {
     "straightwaw": "\u08b1",
     "swashkaf": "\u06aa",
     "syriacwaw": "\u0718",
-    "tah": "\u0637-\u0638\u069f\u088b-\u088c\u08a3",
+    "tah": "\u0637-\u0638\u069f\u088b-\u088c\u08a3\U00010ec3",
     "taw": "\u072c",
     "tehmarbuta": "\u0629\u06c0\u06d5",
     "tehmarbutagoal": "\u06c3",
@@ -203,7 +205,7 @@ unicode_joining_group: dict[str, str] = {
     "thinyeh": "\u0886",
     "verticaltail": "\u088e",
     "waw": "\u0624\u0648\u0676-\u0677\u06c4-\u06cb\u06cf\u0778-\u0779\u08ab",
-    "yeh": "\u0620\u0626\u0649-\u064a\u0678\u06d0-\u06d1\u0777\u08a8-\u08a9\u08ba",
+    "yeh": "\u0626\u0649-\u064a\u0678\u06d0-\u06d1\u0777\u08a8-\u08a9\u08ba",
     "yehbarree": "\u06d2-\u06d3",
     "yehwithtail": "\u06cd",
     "yudh": "\u071d",
@@ -239,6 +241,7 @@ ascii_joining_group: dict[str, str] = {
     "^heth": "\x00-\U0010ffff",
     "^kaf": "\x00-\U0010ffff",
     "^kaph": "\x00-\U0010ffff",
+    "^kashmiriyeh": "\x00-\U0010ffff",
     "^khaph": "\x00-\U0010ffff",
     "^knottedheh": "\x00-\U0010ffff",
     "^lam": "\x00-\U0010ffff",
@@ -343,6 +346,7 @@ ascii_joining_group: dict[str, str] = {
     "heth": "",
     "kaf": "",
     "kaph": "",
+    "kashmiriyeh": "",
     "khaph": "",
     "knottedheh": "",
     "lam": "",
